@@ -11,8 +11,8 @@ from .provider import LinkedInOAuth2Provider
 
 class LinkedInOAuth2Adapter(OAuth2Adapter):
     provider_id = LinkedInOAuth2Provider.id
-    access_token_url = 'https://api.linkedin.com/uas/oauth2/accessToken'
-    authorize_url = 'https://www.linkedin.com/uas/oauth2/authorization'
+    access_token_url = 'https://www.linkedin.com/oauth/v2/accessToken'
+    authorize_url = 'https://www.linkedin.com/oauth/v2/authorization'
     profile_url = 'https://api.linkedin.com/v1/people/~'
     # See:
     # http://developer.linkedin.com/forum/unauthorized-invalid-or-expired-token-immediately-after-receiving-oauth2-token?page=1 # noqa
@@ -26,7 +26,10 @@ class LinkedInOAuth2Adapter(OAuth2Adapter):
     def get_user_info(self, token):
         fields = self.get_provider().get_profile_fields()
         url = self.profile_url + ':(%s)?format=json' % ','.join(fields)
-        resp = requests.get(url, params={'oauth2_access_token': token.token})
+        headers = {}
+        headers.update(self.get_provider().get_settings().get('HEADERS', {}))
+        headers['Authorization'] = ' '.join(['Bearer', token.token])
+        resp = requests.get(url, headers=headers)
         resp.raise_for_status()
         return resp.json()
 
